<?php
namespace Ecommerce\Services;

use Zeedhi\Framework\DTO;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use \Teknisa\Libs\Util\Utilities as LibUtilities;

class PedidoCotacaoService {

    protected $entityManager;
    protected $crudService;
    protected $utilities;

    public function __construct(EntityManager $entityManager, $environment, $crudService,LibUtilities $utilities) 
    {
        $this->entityManager = $entityManager;
        $this->environment   = $environment;
        $this->crudService = $crudService;
        $this->utilities = $utilities;
    }
    
    public function alterarHistnegociapcol(DTO\Request $request, DTO\Response $response) 
    {
        try {
            $this->entityManager->beginTransaction();
            $dataSet = $request->getDataSet()->getRows();
            $sql = "INSERT INTO HISTNEGOCIAPCOL (CDFILIAL, 
                                                 NRPEDIDOCOL, 
                                                 DTINIVALPCOL, 
                                                 DTFINVALPCOL, 
                                                 CDCOMPRADOR, 
                                                 DSOBSRENEGOCIA, 
                                                 CDPRODUTO, 
                                                 CDMARCA, 
                                                 VRUNITATUAL, 
                                                 VRPRECRENEG, 
                                                 VROBJATUAL, 
                                                 IDITPEDPRIONEG, 
                                                 DTOPERHISTPCOL, 
                                                 CDOPERRESP, 
                                                 DTINCLUSAO, 
                                                 NRORG) 
                                         VALUES (:P_CDFILIAL, 
                                                 :P_NRPEDIDOCOL, 
                                                 :P_DTINIVALITM, 
                                                 :P_DTFINVALITM, 
                                                 :P_CDCOMPRADOR, 
                                                 :P_DSOBSRENEGOCIA, 
                                                 :P_CDPRODUTO, 
                                                 :P_CDMARCA, 
                                                 :P_PRUNITATUAL, 
                                                 :P_VRPRECRENEG, 
                                                 :P_PROBJATUAL, 
                                                 :IDITPEDPRIONEG, 
                                                 SYSDATE,
                                                 :CDOPERRESP, 
                                                 SYSDATE,
                                                 :NRORG)";
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            foreach($dataSet as $row) {
                $stmt->execute(
                    array(
                        "P_CDFILIAL"       => $row['CDFILIAL'],
                        "P_NRPEDIDOCOL"    => $row['NRPEDIDOCOL'],
                        "P_DTINIVALITM"    => substr($row['DTINI'], 0, 10),
                        "P_DTFINVALITM"    => substr($row['DTFIN'], 0, 10),
                        "P_CDCOMPRADOR"    => $row['CDCOMPRADOR'],
                        "P_DSOBSRENEGOCIA" => $row['DSOBSRENEGOCIA'],
                        "P_CDPRODUTO"      => $row['CDPRODUTO'],
                        "P_CDMARCA"        => $row['CDMARCA'],
                        "P_PRUNITATUAL"    => $row['VRPRECUNIPRMARC'],
                        "P_VRPRECRENEG"    => $row['VRPRECREN'],
                        "P_PROBJATUAL"     => $row['PRECOOBJETIVO'],
                        "IDITPEDPRIONEG"   => $row['IDITPEDPRIONEG'],
                        "CDOPERRESP"       => $this->environment->getCdOperador(),
                        "NRORG"            => $this->environment->getNrorgTrab()
                    )
                );
            }
            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch (\Exception $e){
            $this->entityManager->rollBack();
            throw $e;
        }
    }
    
    private function createUpdateSql($produto, $condition) 
    {
        $sql = "UPDATE ITEMPEDCOL 
                   SET IDITEMPEDCOLALT = :IDITEMPEDCOLALT,
                       VRITEMPEDCOL    = :VRITEMPEDCOL,
                       VRPRECREN       = :VRPRECREN,
                       NRORGULTATU     = :NRORGULTATU,
                       CDOPERULTATU    = :CDOPERULTATU,
                       VRPERDESPEDCOL  = :VRPERDESPEDCOL,
                       DTULTATU        = SYSDATE
                 WHERE CDFILIAL  = :P_CDFILIAL
                   AND CDMARCA   = :P_CDMARCA
                   AND CDPRODUTO = :P_CDPRODUTO";
                   
        if($condition) {
            $sql = $sql . " AND NVL(VRITEMPEDCOL, 0) > 0";
        }
        
        $sql = $sql . " AND CDFORNECED = :P_CDFORNECED
                        AND EXISTS (SELECT 1
                                      FROM PEDCOLETA
                                     WHERE PEDCOLETA.CDFILIAL    = ITEMPEDCOL.CDFILIAL
                                       AND PEDCOLETA.NRPEDCOLETA = ITEMPEDCOL.NRPEDCOLETA
                                       AND PEDCOLETA.CDREGIAO    = ITEMPEDCOL.CDREGIAO
                                       AND PEDCOLETA.CDFORNECED  = ITEMPEDCOL.CDFORNECED
                                       AND PEDCOLETA.CDFILIAL    = :P_CDFILIAL
                                       AND PEDCOLETA.NRPEDIDOCOL = :P_NRPEDIDOCOL)";
        
        return $sql;
    }
    
    public function atualizaItempedcol($produto, $condition) {
        try {
            $this->entityManager->beginTransaction();
            $sql = $this->createUpdateSql($produto, $condition);
            
            $params = array(
                "IDITEMPEDCOLALT" => $produto['IDITEMPEDCOLALT'],
                "VRITEMPEDCOL"    => $produto['VRPRECUNIPRMARC'],
                "VRPRECREN"       => $produto['VRPRECREN'],
                "VRPERDESPEDCOL"  => $produto['VRPERDESPEDCOL'],
                "NRORGULTATU"     => $this->environment->getNrorgTrab(),
                "CDOPERULTATU"    => $this->environment->getCdoperador(),
                "P_CDFILIAL"      => $produto['CDFILIAL'],
                "P_CDMARCA"       => $produto['CDMARCA'],
                "P_CDPRODUTO"     => $produto['CDPRODUTO'],
                "P_NRPEDIDOCOL"   => $produto['NRPEDIDOCOL'],
                "P_CDFORNECED"    => $produto['CDFORNECED']
            );
                
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute($params);
            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch (\Exception $e){
            $this->entityManager->rollBack();
            throw $e;
        }
    }
    
    public function atualizaValoresAlterados (DTO\Request $request, DTO\Response $response) {
        try {
            $this->entityManager->beginTransaction();
            $rows = $request->getDataSet()->getRows();
            $sql = "UPDATE ITEMPEDCOL SET IDITEMPEDCOLALT = :P_IDITEMPEDCOLALT WHERE CDFILIAL = :P_CDFILIAL AND CDFORNECED = (SELECT CDFORNECED FROM PEDCOLETA WHERE NRPEDIDOCOL = :P_NRPEDIDOCOL) AND CDREGIAO = (SELECT CDREGIAO FROM PEDCOLETA WHERE NRPEDIDOCOL = :P_NRPEDIDOCOL) AND  CDMARCA = :P_CDMARCA AND  CDPRODUTO = :P_CDPRODUTO AND  NRPEDCOLETA = (SELECT NRPEDCOLETA FROM PEDCOLETA WHERE NRPEDIDOCOL = :P_NRPEDIDOCOL)";
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            foreach($rows as $row) {
                $stmt->execute(
                    array(
                        "P_CDFILIAL"        => $row['CDFILIAL'],
                        "P_CDMARCA"         => $row['CDMARCA'],
                        "P_CDPRODUTO"       => $row['CDPRODUTO'],
                        "P_NRPEDIDOCOL"     => $row['NRPEDIDOCOL'],
                        "P_IDITEMPEDCOLALT" => $row['IDITEMPEDCOLALT']
                    )
                );
            }
            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch (\Exception $e){
            $this->entityManager->rollBack();
            throw $e;
        }
    }
    
    public function salvarComentario (DTO\Request $request, DTO\Response $response) {
        try {
            $this->entityManager->beginTransaction();
            $row = $request->getRow();
            
            
            
            if (isset($row["fileUpload"]) && sizeof($row["fileUpload"]) && isset($row["fileUpload"][0]["name"]) && isset($row["fileUpload"][0]["path"])){
                $dsDocumento = $row["fileUpload"][0]["name"];
                $documento = $row["fileUpload"][0]["path"];
            }else{
                $dsDocumento = '';
                $documento = '';
            }
            $sql = "INSERT INTO COMENTPEDCOL (CDFILIAL, NRPEDIDOCOL, DTCOMENTARIO, CDOPERADOR, TXCOMENTARIO, DTINCLUSAO, DTULTATU, NRORG, DSDOCUMENTOANEXO, DSIDDOCFILESERV ) VALUES ( :P_CDFILIAL, :P_NRPEDIDOCOL, SYSDATE, :P_CDOPERADOR, :P_TXCOMENTARIO, SYSDATE, SYSDATE, :NRORG, :DSDOCUMENTOANEXO, :DSIDDOCFILESERV)";
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute(
                array(
                    "P_CDFILIAL"     => $row['CDFILIAL'],
                    "P_NRPEDIDOCOL"  => $row['NRPEDIDOCOL'],
                    "P_CDOPERADOR"   => $this->environment->getCdOperador(),
                    "P_TXCOMENTARIO" => $row['TXCOMENTARIO'],
                    "NRORG"          => $this->environment->getNrorgTrab(),
                    "DSDOCUMENTOANEXO" => $dsDocumento,
                    "DSIDDOCFILESERV" => $documento
                )
            );
            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch (\Exception $e){
            $this->entityManager->rollBack();
            throw $e;
        }
        
        $sql = "SELECT C.CDFILIAL, C.NRPEDIDOCOL, D.CDOPERFORN AS CDOPERADOR, D.NMUSUARIOECO AS NMOPERADOR, C.DTCOMENTARIO, C.TXCOMENTARIO 
                  FROM (SELECT * 
                          FROM COMENTPEDCOL 
                         WHERE CDFILIAL = :P_CDFILIAL 
                           AND NRPEDIDOCOL = :P_NRPEDIDOCOL 
                           AND CDOPERADOR = :P_CDOPERADOR 
                         ORDER BY DTCOMENTARIO DESC) C, DADOSFORNECOMMERCE D 
                  WHERE C.CDOPERADOR = D.CDOPERFORN 
                    AND ROWNUM = 1";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array(
                "P_CDFILIAL"     => $row['CDFILIAL'],
                "P_NRPEDIDOCOL"  => $row['NRPEDIDOCOL'],
                "P_CDOPERADOR"   => $this->environment->getCdOperador()
            )
        );
        return($stmt->fetchAll()[0]);
    }
    
    public function atualizaDesconto (DTO\Request $request, DTO\Response $response) {
        try {
            $this->entityManager->beginTransaction();
            $row = $request->getRow();
            $sql = "UPDATE ITEMPEDCOL SET VRPERDESPEDCOL = :P_VRPERDESPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND CDPRODUTO = :P_CDPRODUTO AND CDMARCA = :P_CDMARCA AND CDFORNECED = :P_CDFORNECED AND EXISTS (SELECT 1 FROM PEDCOLETA WHERE NRPEDIDOCOL = :P_NRPEDIDOCOL AND NRPEDCOLETA = ITEMPEDCOL.NRPEDCOLETA)";
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute(
                array(
                    "P_VRPERDESPEDCOL" => $row['VRPERDESPEDCOL'],
                    "P_CDFILIAL"       => $row['CDFILIAL'],
                    "P_CDPRODUTO"      => $row['CDPRODUTO'],
                    "P_CDMARCA"        => $row['CDMARCA'],
                    "P_CDFORNECED"     => $row['CDFORNECED'],
                    "P_NRPEDIDOCOL"    => $row['NRPEDIDOCOL']
                )
            );
            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch (\Exception $e){
            $this->entityManager->rollBack();
            throw $e;
        }
    }
    
    public function inserirItempedcol($cdfilial, $nrpedcoleta, $cdproduto, $cdmarca) {
        try {
            $this->entityManager->beginTransaction();
            $sql = "INSERT INTO ITEMPEDCOL(CDFILIAL, NRPEDCOLETA, CDFORNECED, CDREGIAO, CDPRODUTO, CDMARCA, VRITEMPEDCOL, VRANTITPEDCOL)
                    SELECT
                       PEDCOLETA.CDFILIAL,
                       PEDCOLETA.NRPEDCOLETA,
                       PEDCOLETA.CDFORNECED,
                       PEDCOLETA.CDREGIAO,
                       PRMARCPEDCOL.CDPRODUTO,
                       PRMARCPEDCOL.CDMARCA,
                       PRMARCPEDCOL.VRPRECUNIPRMARC,
                       PRMARCPEDCOL.VRULTPRECPRMARC
                    FROM PRMARCPEDCOL, PEDCOLETA
                    WHERE PRMARCPEDCOL.CDFILIAL     = :P_CDFILIAL
                      AND PRMARCPEDCOL.NRPEDIDOCOL  = :P_NRPEDIDOCOL
                      AND PRMARCPEDCOL.CDPRODUTO    = :P_CDPRODUTO
                      AND PRMARCPEDCOL.CDMARCA      = :P_CDMARCA
                      AND PEDCOLETA.CDFILIAL        = PRMARCPEDCOL.CDFILIAL
                      AND PEDCOLETA.NRPEDIDOCOL     = PRMARCPEDCOL.NRPEDIDOCOL";
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute(
                array(
                    "P_CDFILIAL" => $cdfilial,
                    "P_NRPEDIDOCOL" => $nrpedcoleta,
                    "P_CDPRODUTO" => $cdproduto,
                    "P_CDMARCA" => $cdmarca
                )
            );
            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch (\Exception $e){
            $this->entityManager->rollBack();
            throw $e;
        }
    }
    
    public function salvarMovopitempedcol(DTO\Request $request, DTO\Response $response) {
		$dataset = $request->getDataSet()->getRows();
		$sql = "SELECT NRPEDCOLETA, CDREGIAO FROM PEDCOLETA WHERE NRPEDIDOCOL = :P_NRPEDIDOCOL";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(array("P_NRPEDIDOCOL" => $dataset[0]['NRPEDIDOCOL']));
		$nrpedcoleta = $stmt->fetchAll();
		
		try {
            $this->entityManager->beginTransaction();
            $sqlInsert = "INSERT INTO MOVOPITEMPEDCOL (CDFILIAL, CDFORNECED, CDMARCA, CDPRODUTO, CDREGIAO, DSALTERITPEDCOL, DSJUSTITPEDCOL, NRPEDCOLETA, NRORG) VALUES (:P_CDFILIAL, :P_CDFORNECED, :P_CDMARCA, :P_CDPRODUTO, :P_CDREGIAO, :P_DSALTERITPEDCOL, :P_DSJUSTITPEDCOL, :P_NRPEDCOLETA, :NRORG)";
            $sqlUpdate = "UPDATE MOVOPITEMPEDCOL SET DSALTERITPEDCOL = :P_DSALTERITPEDCOL, DSJUSTITPEDCOL = :P_DSJUSTITPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND CDFORNECED = :P_CDFORNECED AND CDMARCA = :P_CDMARCA AND CDPRODUTO = :P_CDPRODUTO AND CDREGIAO = :P_CDREGIAO AND NRPEDCOLETA = :P_NRPEDCOLETA AND NRORG = :NRORG";
            
            foreach($dataset as $row) {
                foreach($nrpedcoleta as $nr) {
                    if($this->verificaExisteMovopitempedcol($row, $response) > 0) {
                        $stmt = $this->entityManager->getConnection()->prepare($sqlUpdate);
                    } else {
                        $stmt = $this->entityManager->getConnection()->prepare($sqlInsert);
                    }
                    
                    $stmt->execute(
                        array(
                            "P_CDFILIAL"        => $row['CDFILIAL'],
                            "P_CDFORNECED"      => $row['CDFORNECED'],
                            "P_CDMARCA"         => $row['CDMARCA'],
                            "P_CDPRODUTO"       => $row['CDPRODUTO'],
                            "P_DSALTERITPEDCOL" => $row['DSALTERITPEDCOL'],
                            "P_DSJUSTITPEDCOL"  => $row['DSJUSTITPEDCOL'],
                            "P_CDREGIAO"        => $nr["CDREGIAO"],
                            "P_NRPEDCOLETA"     => $nr["NRPEDCOLETA"],
                            "NRORG"             => $this->environment->getNrorgTrab()
                        )
                    );
                }
            }
            $this->entityManager->flush();
            $this->entityManager->commit();
		} catch (\Exception $e){
            $this->entityManager->rollBack();
            throw $e;
        }
    }
    
    public function verificaExisteMovopitempedcol($row, $response) {
		$sql = "SELECT 1 FROM MOVOPITEMPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND CDFORNECED = :P_CDFORNECED AND CDMARCA = :P_CDMARCA AND CDPRODUTO = :P_CDPRODUTO AND EXISTS (SELECT 1 FROM MOVOPITEMPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND CDFORNECED = :P_CDFORNECED AND CDMARCA = :P_CDMARCA AND CDPRODUTO = :P_CDPRODUTO AND EXISTS (SELECT 1 FROM PEDCOLETA WHERE NRPEDIDOCOL = :P_NRPEDIDOCOL AND NRPEDCOLETA = MOVOPITEMPEDCOL.NRPEDCOLETA) AND NRORG = :NRORG) AND NRORG = :NRORG";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array(
                "P_CDFILIAL"        => $row['CDFILIAL'],
                "P_CDFORNECED"      => $row['CDFORNECED'],
                "P_CDMARCA"         => $row['CDMARCA'],
                "P_CDPRODUTO"       => $row['CDPRODUTO'],
                "P_NRPEDIDOCOL"     => $row['NRPEDIDOCOL'],
                "NRORG"             => $this->environment->getNrorgTrab()
            )
        );
		$result = $stmt->fetchAll();
		return sizeof($result);
	}
    
    public function ACEITA_PEDCOTWEB($params) {
        try {
            $this->entityManager->beginTransaction();
            
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'ACEITA_PEDCOTWEB');
            $procedure->addParam(new Param('P_CDFILIAL',    Param::PARAM_INPUT,  $params['CDFILIAL'],    Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPEDIDOCOL', Param::PARAM_INPUT,  $params['NRPEDIDOCOL'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDCONSISTE',  Param::PARAM_INPUT,  $params['IDCONSISTE'],  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDACEITEOK',  Param::PARAM_OUTPUT, null,                  Param::PARAM_TYPE_STR, 200));
            
            $code = $procedure->execute();
            
            $this->entityManager->flush();
            $this->entityManager->commit();
            return $code;
        } catch (\Exception $e){
            $this->entityManager->rollBack();
            throw $e;
        }
    }
    
    public function alteraStatus($row, $status) {
        $params = [
            "STATUS"       => $status,
            "NRPEDIDOCOL"  => $row["NRPEDIDOCOL"],
            "CDFILIAL"     => $row["CDFILIAL"],
            "NRORG"        => $this->environment->getNrOrgTrab()
        ];
        
        $query1 = "UPDATE PEDCOLETA SET IDSITUPEDCOL = :STATUS WHERE NRPEDIDOCOL = :NRPEDIDOCOL AND CDFILIAL = :CDFILIAL AND NRORG = :NRORG";
        $stmt = $this->entityManager->getConnection()->prepare($query1);
        $stmt->execute($params);
        
        $query2 = "UPDATE PEDCOLGERAL SET IDSITUPEDCOLETA = :STATUS WHERE NRPEDIDOCOL = :NRPEDIDOCOL AND CDFILIAL = :CDFILIAL AND NRORG = :NRORG";
        $stmt = $this->entityManager->getConnection()->prepare($query2);
        $stmt->execute($params);

    }
    
    public function returnParamTermoAceite($cdforneced) {
        
        $query = "SELECT IDUTLCTRLTERMO FROM FORNECEDOR WHERE CDFORNECED = :CDFORNECED AND NRORG = :NRORG";

        $params = [
            "CDFORNECED" => $cdforneced,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        return $std->fetchAll()[0]['IDUTLCTRLTERMO'];
    }
    
    public function validatePassword($cdoperforn, $password) {
		$dataSourceName = 'dadosfornecommerce';
		$conditions = array(
			array(
				'columnName' => 'CDOPERFORN',
				'operator' => '=',
				"value" => $cdoperforn
			)
		);
		$dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();

		if(md5($password) != $dataSet[0]['CDSENHAWEB']){
			throw new \Exception("Usuário e/ou senha inválido(s)!", 1);
		}else{
		    return true;
		}
	}
	
	public function insertAceitePedCol($row) {
	    $query = "INSERT INTO ACEITEPEDCOL (CDFILIAL, NRPEDIDOCOL, CDOPERADOR, IDACEITE, NRORG, DTACEITE) 
	              SELECT :CDFILIAL, :NRPEDIDOCOL, :CDOPERADOR, :IDACEITE, :NRORG, SYSDATE
                    FROM DUAL
                   WHERE NOT EXISTS (SELECT 1
                                       FROM ACEITEPEDCOL
                                      WHERE CDFILIAL = :CDFILIAL
                                        AND NRPEDIDOCOL = :NRPEDIDOCOL
                                        AND CDOPERADOR = :CDOPERADOR
                                        AND IDACEITE = 'S'
                                        AND NRORG = :NRORG
                                        AND IDATIVO = 'S')";
        $params = [
            "CDFILIAL" => $row['CDFILIAL'],
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
            "CDOPERADOR" => $row['OPERADORLOGADO'],
            "IDACEITE" => 'S',
            "NRORG" => $this->environment->getNrOrgTrab()
        ];
        
	    $query2 = "INSERT INTO ACEITEPEDCOL (CDFILIAL, NRPEDIDOCOL, CDOPERADOR, IDACEITE, NRORG, DTACEITE) 
	               SELECT :CDFILIAL, :NRPEDIDOCOL, :CDOPERADOR, :IDACEITE, :NRORG, SYSDATE
                     FROM DUAL
                    WHERE NOT EXISTS (SELECT 1
                                        FROM ACEITEPEDCOL
                                       WHERE CDFILIAL = :CDFILIAL
                                         AND NRPEDIDOCOL = :NRPEDIDOCOL
                                         AND CDOPERADOR = :CDOPERADOR
                                          AND IDACEITE = 'N'
                                         AND NRORG = :NRORG
                                         AND IDATIVO = 'S')";
        $params2 = [
            "CDFILIAL" => $row['CDFILIAL'],
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
            "CDOPERADOR" => $row['COD_RESPONSAVEL'],
            "IDACEITE" => 'N',
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        
        $std2 = $this->entityManager->getConnection()->prepare($query2);
        $std2->execute($params2);
    }
    
    public function buscaCollectionId($row) {
        $sql = "  SELECT FILIAL.CDFILIAL
                    FROM FILIAL, REGIAOPEDCOL
                    WHERE NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = REGIAOPEDCOL.CDFILIAL
                        AND FILIAL.CDREGIAO = REGIAOPEDCOL.CDREGIAO
                        AND REGIAOPEDCOL.CDFILIAL = :P_CDFILIAL
                        AND REGIAOPEDCOL.NRPEDIDOCOL = :P_NRPEDIDOCOL
                        AND NOT EXISTS (SELECT REFOREG.CDREGIAO
                                        FROM REFOREG
                                        WHERE REFOREG.CDREGIAO = FILIAL.CDREGIAO
                                          AND REFOREG.CDFORNECED = :P_CDFORNECED)
                        AND NOT EXISTS (SELECT REFORFIL.CDFILIAL
                                        FROM REFORFIL
                                        WHERE REFORFIL.CDFILIAL = FILIAL.CDFILIAL
                                          AND REFORFIL.CDPERIENTR IS NULL
                                          AND REFORFIL.CDFORNECED = :P_CDFORNECED)";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array(
                "P_CDFILIAL"     => $row['CDFILIAL'],
                "P_NRPEDIDOCOL"  => $row['NRPEDIDOCOL'],
                "P_CDFORNECED"   => $row['CDFORNECED']
            )
        );
        return($stmt->fetchAll());
    }
    
    public function saveCollectedData($row){
        try {
            if(count($row['COLLECTION_IDS']) > 0){
                foreach($row['COLLECTION_IDS'] as $collection_id){
                    $this->utilities->saveCollectedData($collection_id['CDFILIAL'],$row['OPERATION_ID']);
                }
            }
        } catch (\Exception $e){
            $this->entityManager->rollBack();
            throw $e;
        }
    }
}