/**
 * Controller da tela de Pedido de Cotação
 */
function Pedido_Cotacao_Controller(General, templateManager, ScreenService, MessageService, Pedido_Cotacao_Service, PedidoCotacaoService, PadraoExibicao, maskEngine, ZhFilterPreferences, ZhUtil, ZHPromise) {
    /* global $, Constants */ /* global getLocalVar */ 
    let permissaoNegada, errorValue = 0, existeNegociacao = 0;
    let self = this;
    
    this.validaData = function(dtInicial, dtFinal, tipo) {
        const dataInicial = dtInicial ? moment(dtInicial, 'DD/MM/YYYY')._d : null;
        const dataFinal   = dtFinal   ? moment(dtFinal,   'DD/MM/YYYY')._d : null;
        
        if (dataInicial && dataFinal && dataFinal < dataInicial) {
            MessageService.showMessageByCode("invalidDate", {TIPO: tipo}, Constants.alertMessage);
            return false;
        }
        
        return true;
    };
    
/**
 * Verifica se a data passada por parâmetro já expirou em relação a data atual
 */
    let validaExpirado = function(data) {
        let dateFormat = moment(data, 'DD/MM/YYYY HH:mm:SS').format('MM/DD/YYYY HH:mm:SS');
        if(new Date(dateFormat).getTime() > new Date().getTime()) {
            return true;
        }
        return false;
    };
    
/**
 * Seta o valor default em "Situação da Cotação" como "Pendente" e abre o filtro;
 */  
    this.abrirFiltro = function(args) {
        const row = {
            "CDFORNECED": getLocalVar("CDFORNECED")
        };
        
        Pedido_Cotacao_Service.verifyParamTermoAceite(row).then(function(callback) {
            const widget = args.owner;
            const data = callback.dataset.data;
            let filterRow = {};
            
            if (data.PARAMACEITE == "N") {
                filterRow.situacaoCotacao = ['N'];
            } else {
                self.createAdditionalSituationFilters(widget);
                filterRow.situacaoCotacao = ['N', 'C', 'T'];
            }
            
            ZhFilterPreferences.openFilterWidget(widget, filterRow);
        });
    };
    
    this.createAdditionalSituationFilters = function(widget) {
        const additionalFilters = [
            {
                "name": "Aguardando Aceite Fornecedor",
                "value": "T"
            },
            {
                "name": "Aguardando Aceite Comprador",
                "value": "C"
            }
        ];
        
        const defaultFilters = widget.getField("situacaoCotacao").dataSource.data;
        
        Array.prototype.push.apply(defaultFilters, additionalFilters);
        
        widget.getField("situacaoCotacao").dataSource.data = defaultFilters;
    };
    
    this.setCustomFilter = function(args) {
        args.e.preference.CUSTOM_FILTER_ROW = [];
    };
    
    this.setStripeDates = function(widget, startDate, endDate, field) {
        if (startDate && endDate) {
            self.setFieldProperty(widget, field, "isVisible", true);
            widget.currentRow[field] = self.getMessageDate(startDate, endDate);
        } else {
            self.setFieldProperty(widget, field, "isVisible", false);
        }
    };
    
    this.getMessageDate = function(startDate, endDate) {
        return ScreenService.i18n("De ") + startDate + ScreenService.i18n(" até ") + endDate;
    };
    
    this.setFieldProperty = function(widget, field, property, value) {
        widget.getField(field)[property] = value;
    };
    
    this.setStripe = function(args, dtIniExp, dtFinExp, dtIniVal, dtFinVal, pedExpirados) {
        const row = {
            "CDFORNECED": getLocalVar("CDFORNECED")
        };
        let pedidoCotacao = templateManager.container.getWidget("pedidoCotacao");

        Pedido_Cotacao_Service.verifyParamTermoAceite(row).then(function(callback) {
            const data = callback.dataset.data;
            const stripe = templateManager.container.getWidget('STRIPE');
            let rowStripe = stripe.currentRow;
        
            rowStripe.LEGENDAGREEN = ScreenService.i18n("     Enviado e aceito");
    		rowStripe.LEGENDARED = ScreenService.i18n("     Enviado e recusado ");
    		rowStripe.LEGENDAPURPLE = ScreenService.i18n("     Pendente");
    	    rowStripe.LEGENDAORANGE = ScreenService.i18n("     Inconsistências do Pedido");
    	    rowStripe.LEGENDABLUE = ScreenService.i18n("     Aguardando Aceite Fornecedor");
    		rowStripe.LEGENDAPINK = ScreenService.i18n("     Aguardando Aceite Comprador");
    		
    		if (data.PARAMACEITE == "N") {
    		    self.setStripeFieldsVisibility(stripe, false);
    		    self.setStripeFieldsClass(stripe, 3);
    		} else {
    		    self.setStripeFieldsVisibility(stripe, true);
    		    self.setStripeFieldsClass(stripe, 2);
    		}
    		
            self.setStripeDates(stripe, dtIniExp, dtFinExp, "DT_EXPIRACAO");
            self.setStripeDates(stripe, dtIniVal, dtFinVal, "DT_VALIDADE");
            
            let situacoesArray = [];
            let situacoes = args.owner.getField("situacaoCotacao").dataSource.getCheckedRows();
            
            for (let i in situacoes) {
                situacoesArray.push(situacoes[i].name);
            }
            
            situacoes = situacoesArray.join(", ");
            
            if (!pedExpirados) {
                situacoes += " - Pedidos Expirados";
            }
            stripe.currentRow.SITUACAO = situacoes;
            self.setFieldProperty(stripe, "SITUACAO", "isVisible", true);
        }, function(err) {
                ScreenService.showMessage(err.data.error);
                ScreenService.closeSwipe();
                pedidoCotacao.reload();
                pedidoCotacao.activate();
        });
    };
    
    this.setStripeFieldsVisibility = function(stripe, visibility) {
        stripe.getField("LEGENDABLUE").isVisible = visibility;
	    stripe.getField("LEGENDAPINK").isVisible = visibility;
    };
    
    this.setStripeFieldsClass = function(stripe, value) {
        for (let field of stripe.fields) {
            if (field.name.includes("LEGENDA")) {
                field.class = value;
            }
        }
    };
      
    this.confirmarFiltro = function(args) {
        let filtro      = args.owner.appliedFilter.FILTER_ROW;
        let stripe      = templateManager.container.getWidget('STRIPE');
        let dtIniExp    = filtro.INTERVALO_DTEXP ? filtro.INTERVALO_DTEXP.start : "";
        let dtFinExp    = filtro.INTERVALO_DTEXP ? filtro.INTERVALO_DTEXP.end : "";
        let dtIniVal    = filtro.INTERVALO_DTVAL ? filtro.INTERVALO_DTVAL.start : "";
        let dtFinVal    = filtro.INTERVALO_DTVAL ? filtro.INTERVALO_DTVAL.end : "";
        let stPedCol    = filtro.situacaoCotacao.join("_");
        
        if(this.validaData(dtIniExp, dtFinExp, "expiração") && this.validaData(dtIniVal, dtFinVal, "validade")) {
            Pedido_Cotacao_Service.permissaoIncluirProduto().then(function(callback) {
                permissaoNegada = callback.dataset.permissaoIncluirProd[0].IDNPERMANCOTINT;
            });
            
            let datasExpiracao = (!dtIniExp && !dtFinExp)   ? "T" : "";
            let datasValidade  = (!dtIniVal && !dtFinVal)   ? "T" : "";
            let pedExpirados   = (!filtro.PED_EXPIRADOS)    ? "T" : "";
            
            let pedidoCotacao = templateManager.container.getWidget("pedidoCotacao");
            pedidoCotacao.dataSourceFilter = [
                {"name": "P_CDFORNECED",    "operator": "=",  "value": getLocalVar("CDFORNECED")},
                {"name": "P_DTINICIAL",     "operator": "=",  "value": dtIniExp},
                {"name": "P_DTFINAL",       "operator": "=",  "value": dtFinExp},
                {"name": "P_DTVALINI",      "operator": "=",  "value": dtIniVal},
                {"name": "P_DTVALFIN",      "operator": "=",  "value": dtFinVal},
                {"name": "P_TDTVALIDADE",   "operator": "=",  "value": datasValidade},
                {"name": "P_STPEDCOLETA",   "operator": "=",  "value": stPedCol},
                {"name": "P_TEXPIRADAS",    "operator": "=",  "value": pedExpirados},
                {"name": "P_TODOS",         "operator": "=",  "value": datasExpiracao}
            ];
            pedidoCotacao.reload();
            this.setStripe(args, dtIniExp, dtFinExp, dtIniVal, dtFinVal, pedExpirados);
            this.setFilterInfo(pedidoCotacao, filtro, stripe.currentRow.SITUACAO);
            ScreenService.closePopup();
            pedidoCotacao.activate();
        }
    };
    
    this.setFilterInfo = function(widgetPedido, filterRow, situacao) {
        const pedidos = filterRow.PED_EXPIRADOS ? ScreenService.i18n("Sim") : ScreenService.i18n("Não");
        let defaultObject = {};
        let additionalObjectOne = {};
        let additionalObjectTwo = {};
		
		defaultObject = [
		    {"label": ScreenService.i18n("Situação da Cotação"), "value": situacao},
		    {"label": ScreenService.i18n("Pedidos Expirados"),   "value" : pedidos}
	    ];
		
		additionalObjectOne = self.getAdditionalObject(filterRow.INTERVALO_DTEXP, ScreenService.i18n("Data de Expiraçao"));
		additionalObjectTwo = self.getAdditionalObject(filterRow.INTERVALO_DTVAL, ScreenService.i18n("Data de Validade"));
		
		Array.prototype.push.apply(defaultObject, additionalObjectOne);
		Array.prototype.push.apply(defaultObject, additionalObjectTwo);
		
		widgetPedido._filterInfo = defaultObject;
    };
    
    this.getAdditionalObject =  function(date, label) {
        let additionalObject = {};
        
        if(date.start !== "" && date.end !== "") {
            additionalObject = [{"label": label, "value": self.getMessageDate(date.start, date.end)}];
        }
        
        return additionalObject;
    };
    
    /**
     * Verifica se o campo "A Comprar" será exibido no grid" pelo parâmetro "IDEXIBEQTDCMP" do Pedido
     */
    function exibeAComprar(prodCotacaoWidget, idexibeqtdcmp) {
        if(idexibeqtdcmp === 'S') {
            prodCotacaoWidget.getField('QTSOMA').isVisible = true;
        } else {
            prodCotacaoWidget.getField('QTSOMA').isVisible = false;
        }
    }
    
    /**
     *Seta datasourceFilter do grid de produtos
     */    
    function setDsFilterProd(produtos, row) {
        produtos.dataSourceFilter = [
            {"name": "P_CDFORNECED",    "operator": "=",   "value": row.CDFORNECED},
            {"name": "P_CDFILIAL",      "operator": "=",   "value": row.CDFILIAL},
            {"name": "P_NRPEDIDOCOL",   "operator": "=",   "value": row.NRPEDIDOCOL},
            {"name": "P_NRORG",         "operator": "=",   "value": getLocalVar('NRORG')}
        ];
    }
    
    /**
     *Seta datasourceFilter da widget de Comentários
     */    
    function setDsFilterComments(row) {
        const comentarios = templateManager.container.getWidget("comentarios");
        comentarios.dataSourceFilter = [
            {"name": "P_CDFILIAL",      "operator": "=",   "value": row.CDFILIAL},
            {"name": "P_NRPEDIDOCOL",   "operator": "=",   "value": row.NRPEDIDOCOL}
        ];
    }
    
    function concatFornecedores(row) {
        let fornecedor = [];
        
        fornecedor[0]  = PadraoExibicao.mascaraFornecedor(row.IDTPIJURFORN, row.NRINSJURFORN);
        fornecedor[1]  = row.NMRAZSOCFORN;
        row.FORNECEDOR = fornecedor.join(" - ");
    }
    
    /**
     *Retorna regiões no form de detalhes do Pedido de Cotação
     */    
    function returnsRegion(widget, row) {
        Pedido_Cotacao_Service.retornaRegiao(row.CDFILIAL, row.NRPEDIDOCOL).then(function(callback) {
            const regiao = callback.dataset.regiaoCotacao;
            let nomeregiao = [];
            let siglaestado = [];
            
            for(var j = 0; j < regiao.length; j++) {
                siglaestado.push(regiao[j].SIGLAESTADO);
            }
            
            for(var i = 0; i < regiao.length; i++) {
                nomeregiao.push(regiao[i].NOMEREGIAO);
            }
            
            row.NMREGIAO = nomeregiao.join(", ") ;
            row.SGESTADO = siglaestado.join(", ") ;
        });
    }

    this.detalhesPedCotacao = function(pedCotacao) {
        const row = pedCotacao.currentRow;
        const produtos = templateManager.container.getWidget("produtos");
        const filtroPopUp = pedCotacao.appliedFilter.FILTER_ROW;
        
        exibeAComprar(produtos, row.IDEXIBEQTDCMP);
        setDsFilterProd(produtos, row);
        setDsFilterComments(row);
        concatFornecedores(row);
        returnsRegion(produtos, row);
        
        produtos.reload().then(_ => {
            if (row.IDSITUPEDCOLETA !== "N" || validaExpirado(row.DTEXPIRAPEDCOL) === false) {
                produtos.actions.forEach(function(action) {
                    if(action.name == "voltar" || action.name == "voltarView" || action.name == "visualizar") {
                        action.isVisible = true;
                    } else {
                        action.isVisible = false;
                        
                        let arraySituacaoCotacao = filtroPopUp.situacaoCotacao;
                        let aceito = 0;
                        
                        for(var i = 0; i < arraySituacaoCotacao.length; i++) {
                        	aceito = arraySituacaoCotacao[i] == 'A' ? 1 : 0;
                        }
                        
                        produtos.getAction('voltarView').isVisible = (aceito == 1) ? true : false;
                        if(action.name == "openLog" && getLocalVar('IDSISDOS') == 3) {
                            action.isVisible = row.IDSITUPEDCOLETA === 'I';
                        }
                    }
                });
                
                produtos.getAction('devolverAceite').isVisible = (row.IDSITUPEDCOLETA == 'T') ? true : false;
                produtos.getField('VRPRECUNIPRMARC').inlineEditable = false;
                produtos.getField('QTDISPPRODMARC').inlineEditable = false;
                
            } else {
                produtos.actions.forEach(function(action) {
                    action.isVisible = (permissaoNegada == "S" && action.name == "incluirProduto") ? false : true;
                });
                produtos.getField('VRPRECUNIPRMARC').inlineEditable = true;
                produtos.getField('QTDISPPRODMARC').inlineEditable = true;
                produtos.getAction('devolverAceite').isVisible = false;
            }
            if(row.IDSITUPEDCOLETA == 'I') {
                produtos.getAction('devolverAceite').isVisible = false;
                produtos.getAction('aceitar').isVisible = false;
                produtos.getAction('recusar').isVisible = false;
                produtos.getAction('incluirProduto').isVisible = false;
                produtos.getAction('copiarPrecoAnterior').isVisible = false;
                produtos.getAction('abrirReajuste').isVisible = false;
                produtos.getAction('exportarPrecos').isVisible = false;
                produtos.getField('VRPERDESPEDCOL').inlineEditable = false;
                if(getLocalVar('IDSISDOS') == 3){
                    produtos.getAction('openLog').isVisible = true;
                }
            }
            if(getLocalVar('IDSISDOS') == 3) {
                produtos.getField('VRPRECUNIPRMARC').label = ScreenService.i18n("Vr Cotação c/ Impostos");
            } else {
                produtos.getField('VRPRECUNIPRMARC').label = ScreenService.i18n("Vr Cotação");
            }
            
            templateManager.updateTemplate(); 
        });
    };
    
    this.verificaNegociacao = function() {
        const widgetPedidoCotacao = templateManager.container.getWidget('pedidoCotacao');
        const produtos = templateManager.container.getWidget('produtos');
        
        const idrenegociapcol = widgetPedidoCotacao.currentRow.IDRENEGOCIAPCOL;
        const idsitupedcoleta = widgetPedidoCotacao.currentRow.IDSITUPEDCOLETA;
        const filtro = widgetPedidoCotacao.appliedFilter.FILTER_ROW;
        const arrayPedidoCota = filtro.situacaoCotacao;
        const expirados = filtro.PED_EXPIRADOS;
        
        let pendente = 0;
        let aceito = 0;
     
        for (var i = 0; i < arrayPedidoCota.length; i++) {
        	if (arrayPedidoCota[i] == "N") {
        	    pendente = 1;
        	}
        	if (arrayPedidoCota[i] == "A") {
        	    aceito = 1;
        	}
        }
        
        if(idrenegociapcol === 'N') {
            produtos.getField('VRPRECUNIPRMARC').inlineEditable = true;
            produtos.getField('VRPRECREN').isVisible = false;
            
            produtos.getAction('replicarValorObjetivo').isVisible = false;
            produtos.getAction('incluirProduto').isVisible = true;
            produtos.getAction('copiarPrecoAnterior').isVisible = true;
            produtos.getAction('exportarPrecos').isVisible = false;
            produtos.getAction('abrirReajuste').isVisible = true;
        } else {
            produtos.getField('VRPRECUNIPRMARC').inlineEditable = false;
            produtos.getField('VRPRECREN').inlineEditableCondition = 'Pedido_Cotacao_Controller.validaEdicaoVrNegociacao(row);';
            produtos.getField('VRPRECREN').isVisible = true;
            
            produtos.getAction('replicarValorObjetivo').isVisible = true;
            produtos.getAction('incluirProduto').isVisible = false;
            produtos.getAction('copiarPrecoAnterior').isVisible = false;
            produtos.getAction('exportarPrecos').isVisible = false;
            produtos.getAction('abrirReajuste').isVisible = false;
        }
        
        if(expirados || !pendente || idsitupedcoleta != "N") {
            produtos.getAction('replicarValorObjetivo').isVisible = false;
            produtos.getAction('incluirProduto').isVisible = false;
            produtos.getAction('copiarPrecoAnterior').isVisible = false;
            produtos.getAction('exportarPrecos').isVisible = false;    
            produtos.getAction('abrirReajuste').isVisible = false;
            produtos.getField('VRPRECUNIPRMARC').inlineEditable = false;
            produtos.getField('VRPRECREN').inlineEditableCondition = false;
        }
        
        if((idsitupedcoleta == "N" && validaExpirado(produtos.getParent().currentRow.DTEXPIRAPEDCOL)) || idsitupedcoleta == "A") {
            produtos.getAction('exportarPrecos').isVisible = true;
        }
        
        if(permissaoNegada == 'S') {
            produtos.getAction('incluirProduto').isVisible = false;
        }
        
        if(idsitupedcoleta == "I"){
            produtos.getAction('aceitar').isVisible = false;
            produtos.getAction('recusar').isVisible = false;
            produtos.getAction('incluirProduto').isVisible = false;
            produtos.getAction('copiarPrecoAnterior').isVisible = false;
            produtos.getAction('abrirReajuste').isVisible = false;
            produtos.getAction('exportarPrecos').isVisible = false;
        }
        
        if(templateManager.container.getActiveWidget().name == 'produtos') {
            produtos.redraw();
        }
    };
    
    this.voltar = function() {
        ScreenService.closeSwipe();
        templateManager.container.getWidget("pedidoCotacao").list();
        templateManager.container.getWidget("pedidoCotacao").reload();
        templateManager.container.getWidget("pedidoCotacao").activate();
    };
    
    this.visualizar = function(row) {
       let widgetRelatorio = templateManager.container.getWidget("reportWidget");
       ScreenService.openPopup(widgetRelatorio);
    };
    
    this.abrirRelatorio = function(widgetRelatorio) {
        let widgetGrid = templateManager.container.getWidget("pedidoCotacao");
        let row = angular.copy(widgetGrid.currentRow);
        this.defineRelatorio(widgetRelatorio, row);
        ScreenService.closePopup();
    };
    
    function validaAlteracoes(produtos, dtini, dtfin, comprador) {
        let isError = false;
        
        produtos.forEach(function(row) {
            row.QTDISPPRODMARC  = Math.abs(row.QTDISPPRODMARC  ? General.valueToFloat(row.QTDISPPRODMARC)  : 0);
            row.VRPRECUNIPRMARC = Math.abs(row.VRPRECUNIPRMARC ? General.valueToFloat(row.VRPRECUNIPRMARC) : 0);
            row.VRPRECREN       = Math.abs(row.VRPRECREN       ? General.valueToFloat(row.VRPRECREN)       : 0);
            row.DTINI           = dtini;
            row.DTFIN           = dtfin;
            row.CDCOMPRADOR     = comprador;
            let valorAnterior, valorMaximo, valorMinimo, valorAtual;
            let variables = {NMPROD: '', VALUE: ''};
            if(existeNegociacao == 0) {
                valorAtual      = row.VRPRECUNIPRMARC;
                valorAnterior   = General.valueToFloat(row.VRULTPRECPRMARC);
                valorMaximo     = Number((valorAnterior + General.valueToFloat(row.PERCCONSISTENCIA) * valorAnterior / 100).toFixed(3));
                valorMinimo     = Number((valorAnterior - General.valueToFloat(row.PERCMAXDESCONTO)  * valorAnterior / 100).toFixed(3));
            } else {
                valorAtual      = row.VRPRECREN;
                valorAnterior   = General.valueToFloat(row.PRECOOBJETIVO);
                valorMaximo     = Number((valorAnterior + General.valueToFloat(row.PERCCONSISTENCIA) * valorAnterior / 100).toFixed(3));
                valorMinimo     = Number((valorAnterior - General.valueToFloat(row.PERCMAXDESCONTO)  * valorAnterior / 100).toFixed(3));
            }
            if(valorAnterior && valorAtual && valorAtual > valorMaximo && row.PERCCONSISTENCIA)  {
                row.IDITEMPEDCOLALT = 'S'; 
                MessageService.getMessageByCode("value_prod_max").then( (msg) => {
                    variables.NMPROD = row.NOMEPROD;
                    variables.VALUE = valorMaximo.toString().replace('.', ',');
                    row.DSJUSTITPEDCOL = ScreenService.i18n(msg, variables);
                });
                row.DSALTERITPEDCOL = valorAtual;
                errorValue = 1;
                isError = true;
            } else if(valorAnterior && valorAtual && valorAtual < valorMinimo && row.PERCMAXDESCONTO) {
                row.IDITEMPEDCOLALT = 'S';
                MessageService.getMessageByCode("value_prod_min").then( (msg) => {
                    variables.NMPROD = row.NOMEPROD;
                    variables.VALUE = valorMinimo.toString().replace('.', ',');
                    row.DSJUSTITPEDCOL = ScreenService.i18n(msg, variables);
                });
                row.DSALTERITPEDCOL = valorAtual;
                errorValue = 1;
                isError = true;
            } else {
                row.IDITEMPEDCOLALT = 'N';
                row.DSJUSTITPEDCOL = '';
                row.DSALTERITPEDCOL = '';
            }
        });
        
        return isError;
    }
    
    this.salvarEditProdutos = function(widget) {
        if(!widget.isMasterDetailPopup) {
            const pedidos  = templateManager.container.getWidget("pedidoCotacao").currentRow;
            const produtos = widget.dataSource.data.filter(function(row){
                return row.changed == true;
            });
            let prodCopia  = [];
            
            if(validaAlteracoes(produtos, pedidos.DTINIPERGERAL, pedidos.DTFINPERGERAL, pedidos.COD_COMPRADOR)) {
                widget.resizeGridColumns(true);
                widget.updateGridActions();
                return MessageService.showMessageByCode("changeInQuotation", null, Constants.alertMessage);   
            }

            produtos.forEach(function(row) {
                let prodAux = Object.assign({}, row);
                
                delete prodAux.__rightActions;
                delete prodAux.__leftActions;
                
                prodAux.CDFORNECED = pedidos.CDFORNECED;
                
                prodAux.VRPERDESPEDCOL = General.valueToFloat(prodAux.VRPERDESPEDCOL);
                prodAux.VRPRECREN = prodAux.VRPRECREN > 0 ? General.valueToFloat(prodAux.VRPRECREN) : null;
                
                prodCopia.push(prodAux);
            });
            
            widget.updateGridActions();
            General.callRestEngine('product#/salvarProdutos', 'DataSet', prodCopia).then(function(success) {
                widget.commitInlineEdit();
                widget.resizeGridColumns(true);
                widget.reload();    
                MessageService.notificationMessageByCode("successOnSave", null, Constants.successNotification);
            }, function(err) { 
                ScreenService.showMessage(err.data.error);
            });
        } else {
           let vrdesconto = General.valueToFloat(widget.currentRow.VRPERDESPEDCOL);
            if(vrdesconto !== "" && (vrdesconto <= 0 || vrdesconto > 100)) {
                MessageService.showMessageByCode("percentageValidation", null, Constants.alertMessage);
                return false;
            }
            widget.currentRow.VRPERDESPEDCOL = vrdesconto;
            widget.currentRow.CDFORNECED = getLocalVar("CDFORNECED");
            delete widget.currentRow.__rightActions;
            delete widget.currentRow.__leftActions;
            General.callRestEngine('product#/produtos/atualizaDesconto', 'Row', widget.currentRow).then(function(success) {
                widget.view();
                widget.currentRow.VRDESCONTO = widget.currentRow.VRPRECUNIPRMARC * (widget.currentRow.VRPERDESPEDCOL/100);
                templateManager.container.getWidget("graficoNegociacao").enabled = true;
            }, function(err) {
                ScreenService.showMessage(err.data.error);
                
            });
        }
    };
    
    this.copiarPrecoAnterior = function(widget) {
        const pedidos  = templateManager.container.getWidget("pedidoCotacao").currentRow;
        const produtos = widget.dataSource.data.filter(function(row) {
            return row.VRULTPRECPRMARC;
        });
        
        if(!produtos.length) {
            return MessageService.showMessageByCode("noProductsWithPreviousPrice", null, Constants.errorMessage);
        }
        
        MessageService.confirmMessageByCode("copyThePrice").then(() => {
            let prodCopia = [];
            
            produtos.forEach(function(row) {
                //let prodAux = Object.assign({}, row);
                
                row.DTINI           = pedidos.DTINIPERGERAL;
                row.DTFIN           = pedidos.DTFINPERGERAL;
                row.CDCOMPRADOR     = pedidos.COD_COMPRADOR;
                row.CDFORNECED      = pedidos.CDFORNECED;
                row.VRPRECUNIPRMARC = Math.abs(General.valueToFloat(row.VRULTPRECPRMARC));
                row.IDITEMPEDCOLALT = 'N';
                row.VRPRECREN = row.VRPRECREN > 0 ? General.valueToFloat(row.VRPRECREN) : null;
                
                //delete prodAux.__rightActions;
                //delete prodAux.__leftActions;
                
                prodCopia.push(row);
            });
            
            widget.updateGridActions();
            General.callRestEngine('product#/salvarProdutos', 'DataSet', prodCopia).then(function(success) {
                ScreenService.closePopup(true);
                widget.reload();
                MessageService.notificationMessageByCode("successOnUpdatePrices", null, Constants.successNotification);
            }, function(err) {
                ScreenService.showMessage(err.data.error);
                
            });
        });
    };

    this.abrirExportacao = function() {
        ScreenService.openPopup(templateManager.container.getWidget("exportarPrecos"));
    };
    
    this.cancelarExportacao = function(widget) {
        ScreenService.closePopup();
    };
    
    this.setDataSourceFilter = function(widget) {
       let dataSourceFilter = [];
        if (widget.currentRow.periodoExportacao != undefined && widget.currentRow.periodoExportacao != "" && widget.currentRow.periodoExportacao.start != "" && widget.currentRow.periodoExportacao.end != "") {
            dataSourceFilter = [
                {
                    "name": "P_CDFORNECED",
                    "operator": "=",
                    "value": templateManager.container.getWidget("pedidoCotacao").currentRow.CDFORNECED    
                },
                {
                    "name": "P_DTVALINI",
                    "operator": "=",
                    "value": widget.currentRow.periodoExportacao.start
                },
                {
                    "name": "P_DTVALFIN",
                    "operator": "=",
                    "value": widget.currentRow.periodoExportacao.end
                },
                {
                    "name": "P_NRPEDIDOCOL",
                    "operator": "=",
                    "value": templateManager.container.getWidget("pedidoCotacao").currentRow.NRPEDIDOCOL  
                },
                {
                    "name": "P_TDATAS",
                    "operator": "=",
                    "value": ""
                }
            ];
        } else {
            dataSourceFilter = [
                {
                    "name": "P_TDATAS",
                    "operator": "=",
                    "value": "T"
                },
                {
                    "name": "P_NRPEDIDOCOL",
                    "operator": "=",
                    "value": templateManager.container.getWidget("pedidoCotacao").currentRow.NRPEDIDOCOL  
                },
                {
                    "name": "P_CDFORNECED",
                    "operator": "=",
                    "value": templateManager.container.getWidget("pedidoCotacao").currentRow.CDFORNECED    
                }
            ];
        }
        widget.getField('produtoDestino').dataSourceFilter = dataSourceFilter;
        widget.getField('produtoDestino').reload();
    };
    
    this.widgetOnEnterProd = function(widget) {
        this.limparWidgetExportacao(widget);
        widget.reload();
    };
	
    this.limparWidgetExportacao = function(widget) {
        templateManager.container.getWidget("exportarPrecos").currentRow.periodoExportacao = "";
        templateManager.container.getWidget("exportarPrecos").currentRow.produtoDestino = "";
    };
    
    this.registrarLogAcesso = function(widget) {
       let row = {};
        
        row.NRPEDIDOCOL = widget.currentRow.NRPEDIDOCOL;
        row.EMAIL = getLocalVar('EMAIL');
        row.NRORG = getLocalVar('NRORG');
        row.CDFORNECED = widget.currentRow.CDFORNECED;
        row.CDFILIAL = widget.currentRow.CDFILIAL;
        Pedido_Cotacao_Service.registrarAcesso(row).then(function(response) {
        }).catch(function(error) {
            ScreenService.showMessage(error);    
        });
    };
    
    this.confirmarExportacao = function(widget) {
        let dataSet = [];
        if(widget.isValid()) {

            widget.currentRow.produtoDestino.forEach(function(row, index) {
                dataSet.push({
                    CDFILIAL : widget.getParent().getParent().currentRow.CDFILIAL,
                    NRPEDIDOCOLORIGEM : widget.getParent().getParent().currentRow.NRPEDIDOCOL,
                    CHAVE : widget.currentRow.CDFILIAL[index].concat(row).concat(widget.currentRow.CDOPERADOR[index]),
                    NRPEDIDOCOLDEST : row
                });
            });
            Pedido_Cotacao_Service.executarExportacao(dataSet).then(function(response) {
                if (response && response.dataset && response.dataset.pedidosComErro){
                    let erroMessage = response.dataset.pedidosComErro.join(', ');
                    MessageService.showMessageByCode("pedNaoExportado",{erroMessage: erroMessage}).then(function(){
                        ScreenService.closePopup();
                    });
                }else {
                    MessageService.notificationMessageByCode("successOnExport", null, Constants.successNotification);
                    ScreenService.closePopup();
                }
            });
        }    
    };
    
    this.atualizarFrete = function(widget) {
        ScreenService.closePopup(true);
        General.widgetEdit(widget);
        widget.fields.forEach(function(field) {
            if(field.showOnView && field.name !="VRFRETEFORNEPEDCOL") {
                widget.getField(field.name).readOnly = true;
            } 
        });
    };
    
    this.exibirCampoFrete = function(widget) {
       /* TODO verificar como tratar já que pode haver mais de uma regiao
       let row = widget.currentRow;
       let datasExpiracao = templateManager.container.getWidget('produtos').getParent().currentRow.DTEXPIRAPEDCOL;
       let situacao = templateManager.container.getWidget('produtos').getParent().currentRow.IDSITUPEDCOLETA == "N";
        
        Pedido_Cotacao_Service.checarFornecedor(row).then(function(response) {
            if(response.dataset && response.dataset.FORNECEDOR && response.dataset.FORNECEDOR.length) {
                widget.getField('VRFRETEFORNEPEDCOL').isVisible = true;
                if(situacao && validaExpirado(datasExpiracao)) {
                    widget.getAction("valorFrete").isVisible = true;
                    widget.getAction("ACT_SAVE_FRETE").isVisible = true;
                    widget.getAction("ACT_CANCEL_FRETE").isVisible = true;
                } else {
                    widget.getAction("valorFrete").isVisible = false;
                    widget.getAction("ACT_SAVE_FRETE").isVisible = false;
                    widget.getAction("ACT_CANCEL_FRETE").isVisible = false;
                }
            }
        });*/
    };
    
    this.salvarFrete = function(widget) {
       let row = widget.currentRow;
        Pedido_Cotacao_Service.atualizarFrete(row).then(function(response) {
            widget.view();
            widget.reload();
            widget.container.getWidget('produtos').enabled = true;
            widget.container.getWidget('comentarios').enabled = true;
            MessageService.notificationMessageByCode("successOnUpdateValue", null, Constants.successNotification);
        });
    };
    
    this.cancelarAtualizacaoFrete = function(widget) {
        General.widgetCancelForm(widget);
        widget.fields.forEach(function(field) {
            if(field.showOnView) {
                widget.getField(field.name).readOnly = false;
            } 
        });
    };
    
    this.cancelarReajuste = function(widget) {
        ScreenService.closePopup();
        widget.currentRow.valorReajuste = "";
    };
    
    this.confirmarReajuste = function(widget) {
            if(widget.isValid()) {
            const produtos = widget.dataSource.data.filter(function(row){
                return row.VRULTPRECPRMARC;
            });
            
            MessageService.confirmMessageByCode("copyReadjustPrices").then(() => {
                let vrreajuste   = General.valueToFloat(widget.currentRow.valorReajuste);
                let widProdutos  = widget.container.getWidget("produtos");
                let pedidos      = widget.container.getWidget("pedidoCotacao").currentRow;
                let dtini        = pedidos.VALIDADE.split(" ")[0];
                let dtfin        = pedidos.VALIDADE.split(" ")[2];
                let produtos     = [];
                let prodAux;
                
                if(vrreajuste) {
                    widProdutos.dataSource.data.forEach(function(row) {
                        row.CDFORNECED  = pedidos.CDFORNECED;
                        if(row.VRULTPRECPRMARC) {
                            prodAux = Object.assign({}, row);
                            delete prodAux.__rightActions;
                            delete prodAux.__leftActions;
                            produtos.push(prodAux);
                        }
                    });
                    
                    self.validaReajuste(produtos, dtini, dtfin, vrreajuste, pedidos.COD_COMPRADOR).then((prodCopiados) => {
                        return General.callRestEngine('product#/salvarProdutos', 'DataSet', prodCopiados);
                    }).then(() => {
                        widget.currentRow.valorReajuste = "";
                        ScreenService.closePopup(true);
                        widProdutos.resizeGridColumns(true);
                        widProdutos.updateGridActions();
                        widProdutos.commitInlineEdit();
                        widProdutos.reload();
                        widProdutos.activate();
                        MessageService.showMessageByCode("successOnReadjustedObs", null, Constants.successMessage);
                    }).catch(function(error) {
                        ScreenService.showMessage(error);
                    });
                } else {
                    MessageService.showMessageByCode("validPercentReadjust", null, Constants.errorMessage);
                }
            });
        }
    };
    
    this.abrirReajuste = function(widget) {
        const produtos = widget.dataSource.data.filter(function(row) {
            return row.VRULTPRECPRMARC;
        });
        
        if(!produtos.length) {
            return MessageService.showMessageByCode("noProductsWithPreviousPrice", null, Constants.errorMessage);
        }
        
        ScreenService.openPopup(templateManager.container.getWidget("reajuste"));
    };
    
    this.abrirInclusaoProdutos = function(widget) {
       let inclusaoProduto = templateManager.container.getWidget("incluirProduto");
       let pedCotacao = templateManager.container.getWidget("pedidoCotacao");
        Pedido_Cotacao_Service.parasupri(pedCotacao.currentRow.CDFILIAL).then(function(callback) {
            let idutlprocmp = callback.dataset.parasupri[0].IDUTLPROCMP;
            inclusaoProduto.getField("NMPRODUTO").dataSourceFilter = [
                {
                    "name": "P_CDFORNECED",
                    "operator": "=",
                    "value": getLocalVar('CDFORNECED')
                },
                {
                    "name": "P_IDUTLPROCMP",
                    "operator": "=",
                    "value": idutlprocmp
                }
            ];
            ScreenService.openPopup(inclusaoProduto);
        });
    };
    
    this.cancelarInclusao = function(widget) {
        ScreenService.closePopup(true);
        templateManager.container.getWidget("produtos").activate();
        widget.currentRow.NMPRODUTO = "";
        widget.currentRow.NMMARCA   = "";
        widget.getField("NMMARCA").readOnly = true;
    };
    
    this.mudarMarca = function(widget) {
       let pedCotacao = templateManager.container.getWidget("pedidoCotacao");
       let fieldMarca = widget.getField("NMMARCA");
        if(widget.currentRow.NMPRODUTO) {
            fieldMarca.readOnly = false;
            fieldMarca.setValue('');
            let productFilter = fieldMarca.dataSourceFilter.find(filter => filter.name === 'P_CDPRODUTO');
            productFilter.value = widget.currentRow.CDPRODUTO;
            let unitFilter = fieldMarca.dataSourceFilter.find(filter => filter.name === 'P_CDFILIAL');
            unitFilter.value = pedCotacao.currentRow.CDFILIAL;
            let pedidoFilter = fieldMarca.dataSourceFilter.find(filter => filter.name === 'P_NRPEDIDOCOL');
            pedidoFilter.value = pedCotacao.currentRow.NRPEDIDOCOL;
        } else {
            widget.getField("NMMARCA").readOnly = true;
            widget.getField("NMMARCA").setValue('');
        }
    };
    
    this.confirmarInclusao = function(widget) {
        if(widget.isValid()) {
            MessageService.confirmMessageByCode("confirmInclusion").then(() => {
                let produtos    = templateManager.container.getWidget("produtos");
                let pedCotacao  = templateManager.container.getWidget("pedidoCotacao");
                let cdfilial    = pedCotacao.currentRow.CDFILIAL;
                let nrpedidocol = pedCotacao.currentRow.NRPEDIDOCOL;
                let cdproduto   = widget.currentRow.CDPRODUTO;
                let cdarvprod   = widget.currentRow.CDARVPROD;
                let cdmarca     = widget.currentRow.CDMARCA;
                
                Pedido_Cotacao_Service.incluirPrmarcpedcol(cdfilial, cdproduto, nrpedidocol, cdmarca).then(function() {
                    Pedido_Cotacao_Service.inserirItempedcol(cdfilial, nrpedidocol, cdproduto, cdmarca).then(function() {
                        let mask = {
                            "type": "fix",
                            "params": {
                                "mask": "@getLocalVar('CDPICTPROD')@"
                            }
                        };
                        let info = pedCotacao.currentRow;
                        let row = {};
                        let produto = Util.applyMask(cdarvprod, mask, maskEngine, ZhUtil) + " - " + widget.currentRow.NMPRODUTO;
                        let marca   = widget.currentRow.CDMARCA + " - " + widget.currentRow.NMMARCA;
                        let variables = { NMPROD: produto, MARCA: marca};
                        MessageService.getMessageByCode("productInclusion").then( (msg) => {
                            row.TXCOMENTARIO = ScreenService.i18n(msg, variables);
                        });
                        Pedido_Cotacao_Service.salvarComentario(row, info).then(function() {
                            ScreenService.closePopup();
                            produtos.reload();
                            produtos.activate();
                            widget.currentRow.NMPRODUTO = "";
                            widget.currentRow.NMMARCA   = "";
                            widget.getField("NMMARCA").readOnly = true;
                            templateManager.container.getWidget("comentarios").reload();
                            MessageService.notificationMessageByCode("successOnInclusion", null, Constants.successNotification);
                        }, function(err) { 
                            ScreenService.showMessage(retornaMensagemErro(err), 'error');
                            
                        });
                    }, function(err) { 
                        ScreenService.showMessage(retornaMensagemErro(err), 'error');
                        
                    });
                }, function(err) { 
                    ScreenService.showMessage(retornaMensagemErro(err), 'error');
                });
            });
        }
    };
    
    this.replicarValorObjetivo = function(widget) {
        MessageService.confirmMessageByCode("replicateValues").then(() => {
            let pedidos      = templateManager.container.getWidget("pedidoCotacao").currentRow;
            let produtos     = widget.dataSource.data.filter(function(row) {return row.PRECOOBJETIVO !== null;});
            let dtini        = pedidos.VALIDADE.split(" ")[0];
            let dtfin        = pedidos.VALIDADE.split(" ")[2];
            let prodAux      = {};
            let prodCopia    = [];
            
            for(var i in produtos) {
                produtos[i].DTINI           = dtini;
                produtos[i].DTFIN           = dtfin;
                produtos[i].CDCOMPRADOR     = pedidos.COD_COMPRADOR;
                produtos[i].CDFORNECED      = pedidos.CDFORNECED;
                produtos[i].VRPRECREN       = Math.abs(General.valueToFloat(produtos[i].PRECOOBJETIVO));
                produtos[i].IDITEMPEDCOLALT = 'N';
                prodAux = Object.assign({}, produtos[i]);
                
                
                if (produtos[i].VRPRECUNIPRMARC > 0 && produtos[i].VRPRECUNIPRMARC != null) {
                    delete prodAux.__rightActions;
                    delete prodAux.__leftActions;
                    prodAux.addCondition = true;
                    prodCopia.push(prodAux);
                }
            }
            
            General.callRestEngine('product#/salvarProdutos', 'DataSet', prodCopia).then(function(success) {
                ScreenService.closePopup(true);
                widget.reload();
                MessageService.notificationMessageByCode("successOnUpdatePrices", null, Constants.successNotification);
            }, function(err) { 
                ScreenService.showMessage(err.data.error);
                
            });
        });
    };
    
    this.aceitarPedidoCotacao = function() {
        let pedidoCotacao = templateManager.container.getWidget("pedidoCotacao");
        let cdfilial = pedidoCotacao.currentRow.CDFILIAL;
        let nrpedidocol = pedidoCotacao.currentRow.NRPEDIDOCOL;
        
        Pedido_Cotacao_Service.validaItemZero(cdfilial, nrpedidocol).then(function(callback) {
            let itemZerado = callback.dataset.itemZero;
            
            if(itemZerado[0].PRODCOTADO == 0) {
                MessageService.showMessageByCode("emptyQuotation", null, Constants.alertMessage);
            } else {
                if(itemZerado[0].PRODNCOTADO > 0) {
                    MessageService.confirmMessageByCode("acceptSendOrderPrice").then(() => { 
                        self.aceitarPedido();
                    });
                } else {
                    MessageService.confirmMessageByCode("acceptSendOrder").then(() => { 
                        self.aceitarPedido();
                    });
                }
            }
        });
    };
    
    this.openLog = function() {
        const pedidoCotacao = templateManager.container.getWidget("pedidoCotacao").currentRow;
        const widgetLog = templateManager.container.getWidget("logngerapedweb");
                    
        widgetLog.dataSourceFilter = [
			{name: "P_CDFILIAL",	operator: "=",   value: pedidoCotacao.CDFILIAL   },
			{name: "P_NRPEDIDOCOL",	operator: "=",   value: pedidoCotacao.NRPEDIDOCOL},
			{name: [
			    {
                    name : "CDREGIAO",    
                    direction: "ASC"
                },
                {
                    name : "CDFORNECED",    
                    direction: "ASC"
                }
			 ],
             operator: "ORDER_BY",
            }
		];
		
		widgetLog.reload().then(_ => {
            ScreenService.openPopup(widgetLog);
		});
    };
    
    this.cancelLog = function() {
        const widget = templateManager.container.getWidget("logngerapedweb");
        ScreenService.closePopup(true);
        widget.getParent().reload().then(_ => {
            widget.getParent().activate();
        });
    };
    
    this.aceitarSemConsistir = function(){
        const widget = templateManager.container.getWidget("pedidoCotacao");
        const rowPedido = templateManager.container.getWidget("pedidoCotacao").currentRow;
        const dataItens = templateManager.container.getWidget("produtos").dataSource.data;
        
        dataItens.forEach(function(row) {
            row.IDITPEDPRIONEG = 'N';
            row.DSOBSRENEGOCIA = null;
            row.changed  = true;
            row.__is_new = false;
        });
        
        Pedido_Cotacao_Service.aceitarSemConsistir(rowPedido, 'N').then(_ => {
            ZHPromise.all([ScreenService.closePopup(true), ScreenService.closeSwipe(), widget.reload()]).then(widget.activate());
        });
    };
    
    this.aceitarPedido = function() {
        let pedidoCotacao = templateManager.container.getWidget("pedidoCotacao").currentRow;
        let itens = templateManager.container.getWidget("produtos").dataSource.data;
        
        for(let i in itens) {
            itens[i].IDITPEDPRIONEG = 'N';
            itens[i].DSOBSRENEGOCIA = null;
            itens[i].changed  = true;
            itens[i].__is_new = false;
        }
        
        Pedido_Cotacao_Service.aceitaPedidoCotacao(pedidoCotacao, 'S').then(function(callback) {
            let aceiteOk = callback.dataset.idaceiteok[0];
            if(aceiteOk == "OK") {
                self.aceitoSucesso();
            } else if(aceiteOk === 'ERRO') {
                if(getLocalVar('IDSISDOS') == 3){
                    const widgetLog = templateManager.container.getWidget("logngerapedweb");
                    
                    widgetLog.dataSourceFilter = [
            			{name: "P_CDFILIAL",	operator: "=",   value: pedidoCotacao.CDFILIAL   },
            			{name: "P_NRPEDIDOCOL",	operator: "=",   value: pedidoCotacao.NRPEDIDOCOL},
            			{name: [
            			    {
                                name : "CDREGIAO",    
                                direction: "ASC"
                            },
                            {
                                name : "CDFORNECED",    
                                direction: "ASC"
                            }
            			 ],
                         operator: "ORDER_BY",
                        }
            		];
            		widgetLog.reload().then(_ => {
                        ScreenService.openPopup(widgetLog);
            		});
                } else {
                    let row = {
                        "CDFILIAL" :    pedidoCotacao.CDFILIAL,
                        "CDFORNECED" :  pedidoCotacao.CDFORNECED,
                        "NRPEDIDOCOL" : pedidoCotacao.NRPEDIDOCOL,
                        "EMAIL_RESPONSAVEL": pedidoCotacao.EMAIL,
                        "EMAIL_LOGADO": 	 getLocalVar("EMAIL"),
                        "NMRAZSOCFORN": 	 pedidoCotacao.NMRAZSOCFORN,
                        "CDPICTPROD":       getLocalVar("CDPICTPROD").replace(/[^(/\.|\ )]/g, "@"),
                    };
                    General.openReport('product#/sup09400', "SUP09402", row).then(function(callback) {
                        MessageService.showMessageByCode("alertInconsistencies", null, Constants.alertMessage);
                        let widgetProdutos = templateManager.container.getWidget("produtos");
                        widgetProdutos.getAction('aceitar').isVisible = false;
                        widgetProdutos.getAction('recusar').isVisible = false;
                        widgetProdutos.getAction('incluirProduto').isVisible = false;
                        widgetProdutos.getAction('copiarPrecoAnterior').isVisible = false;
                        widgetProdutos.getAction('abrirReajuste').isVisible = false;
                        widgetProdutos.getAction('exportarPrecos').isVisible = false;
                        widgetProdutos.getField('VRPERDESPEDCOL').inlineEditable = false;
                        widgetProdutos.container.getWidget('pedidoCotacao').currentRow.IDSITUPEDCOLETA = 'I';
                        widgetProdutos.getAction('openLog').isVisible = false;
                        widgetProdutos.reload();
                        widgetProdutos.activate();
                    });
                }
            }
        }, function(err) {
            ScreenService.showMessage(err.data.error);
            templateManager.container.getWidget("pedidoCotacao").list();
            templateManager.container.getWidget("pedidoCotacao").reload();
            templateManager.container.getWidget("pedidoCotacao").activate();
            ScreenService.closeSwipe();
        });
    };
    
    this.aceitoSucesso = function() {
        let pedidoCotacao = templateManager.container.getWidget("pedidoCotacao");
        ScreenService.closeSwipe();
        pedidoCotacao.reload();
        pedidoCotacao.activate();
        MessageService.notificationMessageByCode("successOnOrder", null, Constants.successNotification);
    };
    
    this.recusarPedidoCotacao = function() {
        let pedidoCotacao = templateManager.container.getWidget("pedidoCotacao");
         MessageService.confirmMessageByCode("refuseOrder").then(() => { 
            Pedido_Cotacao_Service.recusarCotacao(pedidoCotacao.currentRow, 'R').then(function() {
                ScreenService.closeSwipe();
                pedidoCotacao.reload();
                pedidoCotacao.activate();
                MessageService.notificationMessageByCode("successOnRefusingOrder", null, Constants.successNotification);
            }, function(err) {
                ScreenService.showMessage(err.data.error);
                
            });
        });
    };
    
    this.limpaTela = function(args) {
        let name = "product#Pedido_Cotacao";
        if(templateManager.containers[name]) {
        	delete templateManager.containers[name];
        }
    };
    
    this.abrirInclusaoComentario = function(widget) {
        let inclusaoComentario= widget.container.getWidget("inclusaoComentario");
        inclusaoComentario.currentRow = {};
        ScreenService.openPopup(inclusaoComentario);
    };
    
    this.cancelarComentario = function(widget) {
        widget.currentRow.TXCOMENTARIO = "";
        ScreenService.closePopup();
        widget.getParent().activate();
    };
    
    this.confirmarComentario = function(widget) {
        if(widget.isValid()){
            let info = templateManager.container.getWidget("pedidoCotacao").currentRow;
            
            if(widget.currentRow.fileUpload && widget.currentRow.fileUpload[0] && !widget.currentRow.fileUpload[0].name.split('.')[1]) {
                ScreenService.showMessage('Selecione um arquivo válido.');
                return;
            }
            
            Pedido_Cotacao_Service.salvarComentario(widget.currentRow, info).then(function() {
                ScreenService.closePopup();
                widget.currentRow.TXCOMENTARIO = "";
                widget.getParent().reload();
                widget.getParent().activate();
            }, function(err) {
                ScreenService.showMessage(err.data.error);
            });
        } else {
            MessageService.showMessageByCode("fillRequiredFields", null, Constants.alertMessage);
            
        }
    };
    
    this.downloadAnexo = function (row) {
        delete row.__rightActions;
        delete row.__leftActions;
        General.callRestEngine('product#/setFileFullPath_anexo', 'Row', row).then(function(callback) {
            let infoDocAnexo = callback.dataset.data.row;
            var mappedPackages = templateManager.getMappedServicePackages();
            var baseUrl = mappedPackages.product;
            window.open(baseUrl + "/comentpedcol_download_anexo?requestType=DataSet&dataset[0][DSDOCUMENTOANEXO]=" + infoDocAnexo.DSDOCUMENTOANEXO + "&dataset[0][DOCUMENTOANEXOFULLPATH]=" + infoDocAnexo.DOCUMENTOANEXOFULLPATH);
        });
    };
    
    this.filtraAnexo = function (widget){
        let widgetAnexo = widget.container.getWidget('anexo');
        let currentRow = widget.currentRow;
        widgetAnexo.dataSourceFilter = [
			{name: "P_CDFILIAL",		operator: "=",   value: currentRow.CDFILIAL        },
			{name: "P_NRPEDIDOCOL",	operator: "=",   value: currentRow.NRPEDIDOCOL     },
			{name: "DTCOMENTARIO",	operator: "=",   value: currentRow.DTCOMENTARIO }
		];
        widgetAnexo.reload();
    };
    
    this.closeSecondSwipe = function(widget) {
    	const widgetProdutos = widget.container.getWidget('produtos');
    	
    	if (widgetProdutos.currentRow.CDFILIAL) {
    		ScreenService.closeSwipe();
    		widgetProdutos.currentRow = {};
    	}
    };
    
    this.voltarProdutos = function() {
        const widgetProdutos = templateManager.container.getWidget("produtos");
    	ScreenService.closeSwipe();
    	widgetProdutos.activate();
    	widgetProdutos.currentRow = {};
    };
    
    this.validaReajuste = function(produtos, dtini, dtfin, vrreajuste, comprador) {
        let prodAlterados = [];
        let prodCopiados = [];
        let messages = [];
        let prodAux = {};
        
        messages.push(MessageService.getMessageByCode("value_prod_max"));
        messages.push(MessageService.getMessageByCode("value_prod_min"));
        
        return ZHPromise.all(messages).then((msg) => {
            produtos.forEach(function(row) {
                row.VRPRECUNIPRMARC = Number((General.valueToFloat(row.VRULTPRECPRMARC) * (1 + vrreajuste / 100)).toFixed(3));
                row.DTINI           = dtini;
                row.DTFIN           = dtfin;
                row.CDCOMPRADOR     = comprador;
                row.VRPRECREN       = row.VRPRECREN > 0 ? General.valueToFloat(row.VRPRECREN) : null;
                row.IDITEMPEDCOLALT = 'S';
                row.DSALTERITPEDCOL = row.VRPRECUNIPRMARC;
                let valorAnterior   = General.valueToFloat(row.VRULTPRECPRMARC);
                let valorMaximo     = Number((valorAnterior + General.valueToFloat(row.PERCCONSISTENCIA) * valorAnterior / 100).toFixed(3));
                let valorMinimo     = Number((valorAnterior - General.valueToFloat(row.PERCMAXDESCONTO)  * valorAnterior / 100).toFixed(3));
                let variables = {NMPROD: row.NOMEPROD, VALUE: ''};
    
                if(valorAnterior && row.VRPRECUNIPRMARC && row.VRPRECUNIPRMARC > valorMaximo && row.PERCCONSISTENCIA)  {
                    variables.VALUE = valorMaximo.toString().replace('.', ',');
                    row.DSJUSTITPEDCOL = ScreenService.i18n(msg[0], variables);
                    
                    errorValue = 1;
                } else if(valorAnterior && row.VRPRECUNIPRMARC && row.VRPRECUNIPRMARC < valorMinimo && row.PERCMAXDESCONTO) {
                    variables.VALUE = valorMinimo.toString().replace('.', ',');
                    row.DSJUSTITPEDCOL = ScreenService.i18n(msg[1], variables);
                
                    errorValue = 1;
                } else {
                    row.IDITEMPEDCOLALT = 'N';
                    row.DSJUSTITPEDCOL = '';
                    row.DSALTERITPEDCOL = '';
                    
                    prodAux = Object.assign({}, row);
                    delete prodAux.__rightActions;
                    delete prodAux.__leftActions;
                    prodCopiados.push(prodAux);
                }
                
                if(row.IDITEMPEDCOLALT == 'S') {
                    let dados = {
                        CDFILIAL:        row.CDFILIAL,
                        CDFORNECED:		 getLocalVar("CDFORNECED"),
                        CDMARCA:		 row.CDMARCA,
                        CDPRODUTO:		 row.CDPRODUTO,
                        DSALTERITPEDCOL: row.DSALTERITPEDCOL,
                        DSJUSTITPEDCOL:  row.DSJUSTITPEDCOL,
                        NRPEDIDOCOL:     row.NRPEDIDOCOL
                    };
                    
                    prodAlterados.push(dados);
                }
            });
            
            if(prodAlterados.length > 0) 
                General.callRestEngine("product#/salvarMovopitempedcol", "DataSet", prodAlterados);
                
            return prodCopiados;
        });
    };
    
    this.mostraMensagem = function(row) {
        if(row.DSJUSTITPEDCOL) {
            ScreenService.showMessage(row.DSJUSTITPEDCOL);
        } else {
            let dados = {};
            dados.CDFILIAL    = row.CDFILIAL;
            dados.CDMARCA     = row.CDMARCA;
            dados.CDPRODUTO   = row.CDPRODUTO;
            dados.NRPEDIDOCOL = row.NRPEDIDOCOL;
            dados.CDFORNECED  = getLocalVar("CDFORNECED");
            General.callRestEngine('product#/retornaDados', 'Row', dados).then(function(callback) {
                ScreenService.showMessage(callback.dataset.movopitempedcol[0].DSJUSTITPEDCOL);
            });
        }
    };
    
    this.filtraGrafico = function(widget) {
		let produtos = widget.container.getWidget('produtos').currentRow;
		let pedCotacao = widget.container.getWidget('pedidoCotacao').currentRow;

		widget.dataSourceFilter = [
			{name: "CDFILIAL",		operator: "=",   value: produtos.CDFILIAL        },
			{name: "NRPEDIDOCOL",	operator: "=",   value: produtos.NRPEDIDOCOL     },
			{name: "DTINIVALPCOL",	operator: "=",   value: pedCotacao.DTINIPERGERAL },
			{name: "DTFINVALPCOL",	operator: "=",   value: pedCotacao.DTFINPERGERAL },
			{name: "CDPRODUTO",		operator: "=",   value: produtos.CDPRODUTO       },
			{name: "CDMARCA",		operator: "=",   value: produtos.CDMARCA         }
		];
		
		widget.reload();
	};
	
	this.verificaGrafico = function(widget){
		if (widget.dataSource.data.length <= 0) {
            MessageService.showMessageByCode("insufficientData", null, Constants.alertMessage);
		}
	};
	
	this.commentMessage = function(row) {
        ScreenService.showMessage(row.DSOBSRENEGOCIA, 'information');
    };
    
    function retornaMensagemErro(error) {
        if(error && error.data) {
            return error.data.error;
        } else if(error && error.error) {
            return error.error;
        } else {
            return ScreenService.i18n("Tente novamente.");
        }
    }
    
    this.validaQtdeZeroNegociacao = function(row) {
        const widPedCol = templateManager.container.getWidget('pedidoCotacao');
        if(widPedCol) {
            if(row.IDRENEGOCIAPCOL === 'S') {
                return row.VRPRECUNIPRMARC > 0 ? validaExpirado(widPedCol.currentRow.DTEXPIRAPEDCOL) : false;
            } else {
                return validaExpirado(widPedCol.currentRow.DTEXPIRAPEDCOL);
            }
        }
    };
    
    this.validaEdicaoVrNegociacao = function(row) {
        if (row.IDITPEDPRIONEG == 'S' && row.VRPRECUNIPRMARC > 0) {
            return true;
        } else {
            return false;
        }
    };
    
    this.validaQtdeZeroNegociacaoObservacao = function(row) {
        if(row.DSOBSRENEGOCIA && row.IDITPEDPRIONEG == 'S') {
            return self.validaQtdeZeroNegociacao(row);
        } else {
            return false;
        }
    };
    
    this.defineRelatorio = function(widgetRelatorio, row) {
         row.QR2TYPE = widgetRelatorio.currentRow.QR2TYPE;
        if(getLocalVar('IDSISDOS') == 3) {
           General.openReport("product#/sup09400","SUP09410", row);
        } else {
           General.openReport("product#/sup09400","SUP09400", row);
        }
    };
    
    this.verifyParamTermoAceite = function(widget) {
        Pedido_Cotacao_Service.verifyParamTermoAceite(widget.getParent().currentRow).then(function(response) {
            if(response.dataset.data.PARAMACEITE === 'N'){
                self.aceitarPedidoCotacao();
            }else{
                self.openSwipeAceite(widget);
            }
        });
    };
    
    this.openSwipeAceite = function(widget) {
        let widgetAceite = widget.container.getWidget('ACEITE');
        let fieldPdf = widgetAceite.getField('ACEITE_PDF');
        let widgetGrid = templateManager.container.getWidget("pedidoCotacao"),
        
        row = angular.copy(widgetGrid.currentRow);
        row.QR2TYPE = 'PDF';
        row.__report_name = getLocalVar('IDSISDOS') == 3 ? 'SUP09410' : 'SUP09400';
        
        General.callRestEngine('product#/sup09400', 'Row', row).then(function(callback) {
            let pdfUrl = callback.messages[0].message;
            let htmlPDF = setPdf(fieldPdf, pdfUrl);
            
            ScreenService.openSwipe(widgetAceite).then(function() {
                widgetAceite.currentRow =[];
                widgetAceite.currentRow.URL = pdfUrl;
                let fieldSelector = $("#ACEITE_PDF");
                let heightPDF = String(window.screen.availHeight - 290)+"px";
                htmlPDF = htmlPDF.replace("<>heightPDF<>", heightPDF);
                fieldSelector.parent()[0].innerHTML = htmlPDF;
                widgetAceite.edit();
                templateManager.updateTemplate();
            });
        });
    };
    
    var setPdf = function(field, pdfUrl) {
        var value = "<embed src = "+ pdfUrl + "#page=1&zoom=109' width='100%' height='100%' type='application/pdf' style='height: <>heightPDF<>'>";
        field.value(value);
        return value;
    };
    
    this.backAceite = function() {
        ScreenService.closeSwipe();
    };
    
    this.confirmaTermoAceite = function(widget) {
        let currentRow = {};
        Object.assign(currentRow, widget.currentRow);
        if(widget.isValid() && currentRow.ID_AGREED === 'S') {
            let widgetPedido = widget.container.getWidget('pedidoCotacao');
            currentRow.EMAIL_LOGADO = getLocalVar('EMAIL');
            currentRow.OPERADORLOGADO = getLocalVar('CDOPERADOR');
            currentRow.NMOPERADORLOGADO = getLocalVar('NMOPERADOR');
            currentRow.FILIALLOGADA = getLocalVar('CDFILIAL');
            currentRow.DATA = moment().format('DD/MM/YYYY');
            currentRow.HORA = moment().format('HH:mm:ss');
            currentRow.NRPEDIDOCOL = widgetPedido.currentRow.NRPEDIDOCOL;
            currentRow.EMAIL_RESPONSAVEL = widgetPedido.currentRow.EMAIL;
            currentRow.COD_RESPONSAVEL = widgetPedido.currentRow.COD_RESPONSAVEL;
            currentRow.CDFILIAL = widgetPedido.currentRow.CDFILIAL;
            General.callRestEngine('product#/authOperConfirmaTermo', 'Row', currentRow).then(function(callback) {
                ScreenService.closeSwipe();
                let widgetProdutos = widget.container.getWidget('produtos');
                widgetProdutos.getAction('devolverAceite').isVisible = false;
                widgetProdutos.reload();
                widgetProdutos.activate();
                MessageService.notificationMessageByCode("successOnAccept", null, Constants.successNotification);
            }, function(err) { 
                ScreenService.showMessage(err.data.error);
                ScreenService.closeSwipe().then(function(){
                    ScreenService.closeSwipe();
                    templateManager.container.getWidget("pedidoCotacao").list();
                    templateManager.container.getWidget("pedidoCotacao").reload();
                    templateManager.container.getWidget("pedidoCotacao").activate();
                });
            });
        } else {
             MessageService.showMessageByCode("validateAcceptTerm", null, Constants.alertMessage);
        }
    };
    
    this.verificaIdSisDos = function() {
        	General.callRestEngine("product#/verificaIdSisDos", "DataSet", []).then(function(callback) {
			let idSisDos = callback.dataset.resp.IDSISDOS;
            setLocalVar('IDSISDOS', idSisDos);
        });
    };
    
    this.saveCollectedData = function(widget){
        let row = {
            "CDFORNECED"     : getLocalVar('CDFORNECED'),
            "CDFILIAL"       : widget.currentRow.CDFILIAL,
            "NRPEDIDOCOL"    : widget.currentRow.NRPEDIDOCOL,
            "COLLECTION_IDS" : null,
            "OPERATION_ID"   : 'Utilização do portal E-commerce - Pedido de Cotação',
        };
        
    	General.callRestEngine("product#/saveCollectedData", "Row", row);
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register('Pedido_Cotacao_Controller', Pedido_Cotacao_Controller);
});